@@ -27,7 +27,7 @@ Bootstrap-styled versions of Forms, Inputs and related Layouts.
 from reahl.component.exceptions import arg_checks, IsInstance, ProgrammerError
 from reahl.component.i18n import Catalogue
 from reahl.component.modelinterface import BooleanField, MultiChoiceField, Choice, Field, ChoiceField
-from reahl.component.modelinterface import exposed, Event, Action
+from reahl.component.modelinterface import Event, Action
 
 import reahl.web.ui
 from reahl.web.fw import Layout, ValidationException
@@ -75,9 +75,7 @@ class TextInput(reahl.web.ui.TextInput):
                      such "fuzzy input". If fuzzy=True, the typed value will be changed on the fly to
                      the system's interpretation of what the user originally typed as soon as the TextInput
                      looses focus.
-       :keyword placeholder: If given a string, placeholder is displayed in the TextInput if the TextInput
-                     is empty in order to provide a hint to the user of what may be entered into the TextInput.
-                     If given True instead of a string, the label of the TextInput is used.
+       :keyword placeholder: (See :class:`~reahl.web.ui.TextInput`)
        :keyword refresh_widget: (See :class:`~reahl.web.ui.PrimitiveInput`)
        :keyword ignore_concurrent_change: (See :class:`~reahl.web.ui.PrimitiveInput`)
 
@@ -86,6 +84,10 @@ class TextInput(reahl.web.ui.TextInput):
 
        .. versionchanged:: 5.0
           Added `ignore_concurrent_change`
+
+       .. versionchanged:: 6.1
+          Changed `placeholder to display the default of the field under certain conditions`
+
     """
     def __init__(self, form, bound_field, fuzzy=False, placeholder=False, refresh_widget=None, ignore_concurrent_change=False):
         super().__init__(form, bound_field, fuzzy=fuzzy, placeholder=placeholder, refresh_widget=refresh_widget, ignore_concurrent_change=ignore_concurrent_change)
@@ -138,6 +140,7 @@ class SelectInput(reahl.web.ui.SelectInput):
 
        :param form: (See :class:`~reahl.web.ui.Input`)
        :param bound_field: (See :class:`~reahl.web.ui.Input`)
+       :keyword size: Number of rows in the list that should be visible at one time, if the associated field allows multiple selections.
        :keyword refresh_widget: (See :class:`~reahl.web.ui.PrimitiveInput`)
        :keyword ignore_concurrent_change: (See :class:`~reahl.web.ui.PrimitiveInput`)
 
@@ -147,8 +150,8 @@ class SelectInput(reahl.web.ui.SelectInput):
        .. versionchanged:: 5.0
           Added `ignore_concurrent_change`
     """
-    def __init__(self, form, bound_field, refresh_widget=None, ignore_concurrent_change=False):
-        super().__init__(form, bound_field, refresh_widget=refresh_widget, ignore_concurrent_change=ignore_concurrent_change)
+    def __init__(self, form, bound_field, size=None, refresh_widget=None, ignore_concurrent_change=False):
+        super().__init__(form, bound_field, size=size, refresh_widget=refresh_widget, ignore_concurrent_change=ignore_concurrent_change)
         self.append_class('custom-select')
 
 
@@ -585,6 +588,25 @@ class InlineFormLayout(FormLayout):
         help_text.append_class('ml-2')
         return help_text
 
+    def add_input(self, html_input, hide_label=False, help_text=None, space_before=False, space_after=False):
+        """Adds an input to the Form.
+
+           :param html_input: (See :meth:`~reahl.web.bootstrap.Forms.FormLayout.add_input`).
+           :keyword hide_label: (See :meth:`~reahl.web.bootstrap.Forms.FormLayout.add_input`).
+           :keyword help_text: (See :meth:`~reahl.web.bootstrap.Forms.FormLayout.add_input`).
+           :keyword space_before: If True, render with a margin before the input.
+           :keyword space_after: If True, render with a margin after the input.
+
+           .. versionchanged:: 6.1
+              Added space_before and space_after kwargs.
+        """
+        added = super().add_input(html_input, hide_label=hide_label, help_text=help_text)
+        if space_before:
+            added.append_class('ml-2')
+        if space_after:
+            added.append_class('mr-2')
+        return added
+    
 
 class MarginLayout(Layout):
     """
